pub fn execute(plans: &[RenamePlan]) -> Result<ExecutionReport, FrenError>Expand description
Apply a sorted plan vector with no transaction logging.
Equivalent to execute_with_log using a NullLogSink. Convenience
for tests and quick scripts.
pub fn execute(plans: &[RenamePlan]) -> Result<ExecutionReport, FrenError>Apply a sorted plan vector with no transaction logging.
Equivalent to execute_with_log using a NullLogSink. Convenience
for tests and quick scripts.